@@ -1,7 +1,7 @@
 package Data::Clean;
 
-our $DATE = '2016-05-28'; # DATE
-our $VERSION = '0.36'; # VERSION
+our $DATE = '2016-05-31'; # DATE
+our $VERSION = '0.37'; # VERSION
 
 use 5.010001;
 use strict;
@@ -81,6 +81,13 @@ sub command_unbless {
     );
 }
 
+# for testing only
+sub command_unbless_pp {
+    my ($self, $args) = @_;
+
+    "{{var}} = Function::Fallback::CoreOrPP::_unbless_fallback({{var}}); \$ref = ref({{var}})";
+}
+
 sub command_clone {
     my $clone_func;
     eval { require Data::Clone };
@@ -272,7 +279,7 @@ Data::Clean - Clean data structure
 
 =head1 VERSION
 
-This document describes version 0.36 of Data::Clean (from Perl distribution Data-Clean), released on 2016-05-28.
+This document describes version 0.37 of Data::Clean (from Perl distribution Data-Clean), released on 2016-05-31.
 
 =head1 SYNOPSIS
 
